@@ -30,12 +30,12 @@ use List::Compare;
 use List::MoreUtils qw(any none);
 use Path::Tiny;
 use Text::Levenshtein qw(distance);
-use XML::Simple qw(:strict);
+use XML::LibXML;
 
 use Lintian::Data;
 use Lintian::Deb822Parser qw(read_dpkg_control parse_dpkg_control);
 use Lintian::Relation::Version qw(versions_compare);
-use Lintian::Spelling qw(check_spelling spelling_tag_emitter);
+use Lintian::Spelling qw(check_spelling);
 use Lintian::Util qw(file_is_encoded_in_non_utf8);
 
 use constant {
@@ -52,9 +52,10 @@ use constant {
 use constant {
     WC_TYPE_REGEX => 'REGEX',
     WC_TYPE_FILE => 'FILE',
-    WC_TYPE_DECENDANTS => 'DECENDANTS',
+    WC_TYPE_DESCENDANTS => 'DESCENDANTS',
 };
 
+use constant EMPTY => q{};
 use constant SPACE => q{ };
 
 use Moo;
@@ -66,9 +67,6 @@ our $KNOWN_ESSENTIAL = Lintian::Data->new('fields/essential');
 our $KNOWN_COMMON_LICENSES
   =  Lintian::Data->new('copyright-file/common-licenses');
 
-my $SPELLING_ERROR_IN_COPYRIGHT
-  = spelling_tag_emitter('spelling-error-in-copyright');
-
 my $BAD_SHORT_LICENSES = Lintian::Data->new(
     'source-copyright/bad-short-licenses',
     qr/\s*\~\~\s*/,
@@ -89,18 +87,25 @@ my %dep5_renamed_fields        = (
     'name'                 => 'upstream-name',
 );
 
+sub spelling_tag_emitter {
+    my ($self, @orig_args) = @_;
+    return sub {
+        return $self->tag(@orig_args, @_);
+    };
+}
+
 sub source {
     my ($self) = @_;
 
-    my $info = $self->info;
+    my $processable = $self->processable;
     my $group = $self->group;
 
-    my $debian_dir = $info->index_resolved_path('debian/');
+    my $debian_dir = $processable->index_resolved_path('debian/');
     return if not $debian_dir;
     my $copyright_path = $debian_dir->child('copyright');
 
     if (not $copyright_path) {
-        my @pkgs = $info->binaries;
+        my @pkgs = $processable->binaries;
         $self->tag('no-debian-copyright');
         if (scalar @pkgs == 1) {
             # If debian/copyright doesn't exist, and the only a single
@@ -187,7 +192,7 @@ sub find_dep5_version {
 sub check_apache_notice_files {
     my ($self, $contents) = @_;
 
-    my $info = $self->info;
+    my $processable = $self->processable;
     my $group = $self->group;
 
     my @procs = $group->get_processables('binary');
@@ -198,12 +203,12 @@ sub check_apache_notice_files {
               $_->basename =~ m/^NOTICE(\.txt)?$/
           and $_->is_open_ok
           and $_->file_contents =~ m/apache/i
-    } $info->sorted_index;
+    } $processable->sorted_index;
     return if not @notice_files;
 
     foreach my $binpkg (@procs) {
-        my @files = map { $_->name } $binpkg->info->sorted_index;
-        my $java_info = $binpkg->info->java_info;
+        my @files = map { $_->name } $binpkg->sorted_index;
+        my $java_info = $binpkg->java_info;
         for my $jar_file (sort keys %{$java_info}) {
             push @files, keys %{$java_info->{$jar_file}{files}};
         }
@@ -219,7 +224,7 @@ sub check_apache_notice_files {
 sub check_dep5_copyright {
     my ($self, $contents) = @_;
 
-    my $info = $self->info;
+    my $processable = $self->processable;
 
     my (@dep5, @lines);
 
@@ -305,7 +310,7 @@ sub check_dep5_copyright {
 sub parse_dep5 {
     my ($self, $dep5ref, $linesref) = @_;
 
-    my $info = $self->info;
+    my $processable = $self->processable;
     my @dep5       = @$dep5ref;
     my @lines      = @$linesref;
     my $first_para = shift @dep5;
@@ -327,10 +332,11 @@ sub parse_dep5 {
         'format',"(line $lines[0]{'format'})")
       if none { defined $first_para->{$_} } qw(format format-specification);
     $self->tag('missing-explanation-for-contrib-or-non-free-package')
-      if $info->source_field('section', '') =~ m{^(contrib|non-free)(/.+)?$}
+      if $processable->source_field('section', '')
+      =~ m{^(contrib|non-free)(/.+)?$}
       and none { defined $first_para->{$_} } qw(comment disclaimer);
     $self->tag('missing-explanation-for-repacked-upstream-tarball')
-      if $info->repacked
+      if $processable->repacked
       and none { defined $first_para->{$_} } qw(comment files-excluded)
       and ($first_para->{'source'} // '') =~ m{^https?://};
 
@@ -348,17 +354,24 @@ sub parse_dep5 {
         }
     }
 
-    my @shippedfiles = sort grep { $_->is_file } $info->sorted_index;
+    my @shipped = $processable->sorted_orig_index;
+
+    my $debian_dir = $processable->index_resolved_path('debian/');
+    if ($debian_dir) {
+
+        push(@shipped, $debian_dir->children('breadth-first'));
+    }
+
+    my @shippedfiles = sort grep { $_->is_file } @shipped;
 
     my @licensefiles= grep { m,(^|/)(COPYING[^/]*|LICENSE)$, } @shippedfiles;
-
     my @quiltfiles = grep { m,^\.pc/, } @shippedfiles;
 
     my (@commas_in_files, %file_para_coverage, %file_licenses);
     my %file_coverage = map { $_ => 0 } @shippedfiles;
     my $i = 0;
     my $current_line = 0;
-    my $commas_in_files = any { m/,/xsm } $info->sorted_index;
+    my $commas_in_files = any { m/,/xsm } @shipped;
 
     for my $para (@dep5) {
         $i++;
@@ -460,29 +473,46 @@ sub parse_dep5 {
 
                     my $used = 0;
                     $file_para_coverage{$current_line} = 0;
+
                     if ($wc_type eq WC_TYPE_FILE) {
                         if (exists($file_coverage{$wc_value})) {
                             $used = 1;
                             $file_coverage{$wildcard} = $current_line;
                             $file_licenses{$wildcard} = $short_license;
                         }
-                    } elsif ($wc_type eq WC_TYPE_DECENDANTS) {
+
+                    } elsif ($wc_type eq WC_TYPE_DESCENDANTS) {
                         my @wlist;
-                        if (my $dir = $info->index($wc_value)) {
-                            if ($wc_value eq q{}) {
-                                # Special-case => Files: *
-                                push(@wlist, @shippedfiles);
-                            } else {
-                                push(@wlist,
-                                    grep { $_->is_file }
-                                      $dir->children('breadth-first'));
+
+                        if ($wc_value eq q{}) {
+                            # Special-case => Files: *
+                            push(@wlist, @shippedfiles);
+
+                        } elsif ($wc_value =~ /^debian\//) {
+                            my $dir = $processable->index($wc_value);
+                            if ($dir) {
+                                my @files = grep { $_->is_file }
+                                  $dir->children('breadth-first');
+                                push(@wlist, @files);
+                            }
+
+                        } else {
+                            my $dir = $processable->orig_index($wc_value);
+                            if ($dir) {
+                                my @files = grep { $_->is_file }
+                                  $dir->children('breadth-first');
+                                push(@wlist, @files);
                             }
-                            $used = 1 if @wlist;
                         }
+
+                        $used = 1
+                          if @wlist;
+
                         for my $entry (@wlist) {
                             $file_coverage{$entry->name} = $current_line;
                             $file_licenses{$entry->name} = $short_license;
                         }
+
                     } else {
                         for my $srcfile (@shippedfiles) {
                             if ($srcfile =~ $wc_value) {
@@ -558,20 +588,37 @@ sub parse_dep5 {
             $lines[$paragraph_no]{$field_name});
     } else {
         foreach my $srcfile (sort keys %file_licenses) {
-            next if $srcfile =~ '^\.pc/';
-            next unless $srcfile =~ /\.xml$/;
-            my $file = $info->index_resolved_path($srcfile);
-            my $seen = eval {
-                my $xml
-                  = XMLin($file->fs_path, ForceArray => [], KeyAttr => []);
-                lc($xml->{'metadata_license'} // '');
-            };
-            next unless $seen;
+            next
+              if $srcfile =~ '^\.pc/';
+            next
+              unless $srcfile =~ /\.xml$/;
+
+            my $parser = XML::LibXML->new;
+            $parser->set_option('no_network', 1);
+
+            my $file = $processable->index_resolved_path($srcfile);
+            my $doc = eval {$parser->parse_file($file->fs_path);};
+            next
+              unless $doc;
+
+            my @nodes = $doc->findnodes('/component/metadata_license');
+            next
+              unless @nodes;
+
+            # take first one
+            my $first = $nodes[0];
+            next
+              unless $first;
+
+            my $seen = lc($first->firstChild->data // EMPTY);
+            next
+              unless $seen;
+
             my $wanted = $file_licenses{$srcfile};
             $self->tag('inconsistent-appstream-metadata-license',
                 $srcfile,"($seen != $wanted)")
               unless $seen eq $wanted
-              or $info->name eq 'lintian';
+              or $processable->name eq 'lintian';
         }
 
         my @no_license_needed = (@quiltfiles, @licensefiles);
@@ -589,6 +636,7 @@ sub parse_dep5 {
             "paragraph at line $_")
           for sort keys %file_para_coverage;
     }
+
     while ((my $license, $i) = each %required_standalone_licenses) {
         if (not defined $standalone_licenses{$license}) {
             $self->tag('missing-license-paragraph-in-dep5-copyright',
@@ -650,6 +698,11 @@ sub parse_license {
     }else {
         $short_license = $license_block;
     }
+    if(defined $full_license) {
+        $self->tag('tab-in-license-text',
+            "debian/copyright (paragraph at line $line)")
+          if $full_license =~ /\t/;
+    }
     $short_license =~ s/[(),]/ /g;
     if ($short_license =~ m/\A\s*\Z/) {
         $self->tag('empty-short-license-in-dep5-copyright',
@@ -713,7 +766,7 @@ sub parse_wildcard {
     $regex_src =~ s,^\./+,,;
     $regex_src =~ s,//+,/,g;
     if ($regex_src eq '*') {
-        return ('', WC_TYPE_DECENDANTS, undef);
+        return ('', WC_TYPE_DESCENDANTS, undef);
     }
     if (index($regex_src, '?') == -1) {
         my $star_index = index($regex_src, '*');
@@ -732,7 +785,7 @@ sub parse_wildcard {
             if ($bslash_index > -1) {
                 ($regex_src, $error) = dequote_backslashes($regex_src);
             }
-            return ($regex_src, WC_TYPE_DECENDANTS, $error);
+            return ($regex_src, WC_TYPE_DESCENDANTS, $error);
         }
     }
 
@@ -768,9 +821,9 @@ sub parse_wildcard {
 sub check_files_excluded {
     my ($self, $excluded) = @_;
 
-    my $info = $self->info;
+    my $processable = $self->processable;
 
-    my @files = grep { $_->is_file } $info->sorted_orig_index;
+    my @files = grep { $_->is_file } $processable->sorted_orig_index;
     my @wildcards = split /[\n\t ]+/, $excluded;
     for my $wildcard (@wildcards) {
         $wildcard =~ s/^\s+|\s+$//g;
@@ -815,20 +868,19 @@ sub binary {
     my ($self) = @_;
 
     my $pkg = $self->package;
-    my $info = $self->info;
-    my $proc = $self->processable;
+    my $processable = $self->processable;
     my $group = $self->group;
 
     my $found = 0;
     my $linked = 0;
     my $path = "usr/share/doc/$pkg";
 
-    if ($info->index("$path/copyright.gz")) {
+    if ($processable->index("$path/copyright.gz")) {
         $self->tag('copyright-file-compressed');
         $found = 1;
     }
 
-    if (my $index_info = $info->index("$path/copyright")) {
+    if (my $index_info = $processable->index("$path/copyright")) {
         $found = 1;
         if ($index_info->is_symlink) {
             $self->tag('copyright-file-is-symlink');
@@ -839,7 +891,7 @@ sub binary {
     }
 
     if (not $found) {
-        my $index_info = $info->index($path);
+        my $index_info = $processable->index($path);
         if (defined $index_info && $index_info->is_symlink) {
             my $link = $index_info->link;
 
@@ -867,7 +919,7 @@ sub binary {
             # We therefore just require the dependency for now and
             # don't worry about the version number.
             $link =~ s,/.*,,;
-            if (not depends_on($info, $proc, $link)) {
+            if (not depends_on($processable, $link)) {
                 $self->tag('usr-share-doc-symlink-without-dependency', $link);
                 return;
             }
@@ -883,7 +935,7 @@ sub binary {
         return;
     }
 
-    my $dcopy = $info->lab_data_path('copyright');
+    my $dcopy = path($processable->groupdir)->child('copyright')->stringify;
     # check that copyright is UTF-8 encoded
     my $line = file_is_encoded_in_non_utf8($dcopy);
     if ($line) {
@@ -1105,8 +1157,11 @@ qr/GNU (?:Lesser|Library) General Public License|(?-i:\bLGPL\b)/i
                |\bpublic(?:\s+|-)domain\b/xi;
     }
 
-    check_spelling($_, $group->info->spelling_exceptions,
-        $SPELLING_ERROR_IN_COPYRIGHT, 0);
+    check_spelling(
+        $_,
+        $group->info->spelling_exceptions,
+        $self->spelling_tag_emitter('spelling-error-in-copyright'), 0
+    );
 
     # Now, check for linking against libssl if the package is covered
     # by the GPL.  (This check was requested by ftp-master.)  First,
@@ -1116,10 +1171,10 @@ qr/GNU (?:Lesser|Library) General Public License|(?-i:\bLGPL\b)/i
     if ($gpl || m,/usr/share/common-licenses/GPL,) {
         unless (m,exception|exemption|/usr/share/common-licenses/(?!GPL)\S,){
             my @depends;
-            if (my $field = $info->field('depends')) {
+            if (my $field = $processable->field('depends')) {
                 @depends = split(/\s*,\s*/, $field);
             }
-            if (my $field = $info->field('pre-depends')) {
+            if (my $field = $processable->field('pre-depends')) {
                 push(@depends, split(/\s*,\s*/, $field));
             }
             if (any { /^libssl[0-9.]+(?:\s|\z)/ && !/\|/ } @depends) {
@@ -1133,15 +1188,15 @@ qr/GNU (?:Lesser|Library) General Public License|(?-i:\bLGPL\b)/i
 
 # -----------------------------------
 
-# Returns true if the package whose information is in $info depends $package
+# Returns true if the package whose information is in $processable depends $package
 # or if $package is essential.
 sub depends_on {
-    my ($info, $proc, $package) = @_;
+    my ($processable, $package) = @_;
     my ($strong, $arch);
     return 1 if $KNOWN_ESSENTIAL->known($package);
-    $strong = $info->relation('strong');
+    $strong = $processable->relation('strong');
     return 1 if $strong->implies($package);
-    $arch = $proc->pkg_arch;
+    $arch = $processable->architecture;
     return 1 if $arch ne 'all' and $strong->implies("${package}:${arch}");
     return 0;
 }
@@ -1154,14 +1209,14 @@ sub check_cross_link {
     my $src = $group->source;
     if ($src) {
         # source package is available; check it's list of binary
-        return if defined $src->info->binary_package_type($fpkg);
+        return if defined $src->binary_package_type($fpkg);
         $self->tag('usr-share-doc-symlink-to-foreign-package', $fpkg);
     } else {
         # The source package is not available, but the binary could
         # be present anyway;  If they are in the same group, they claim
         # to have the same source (and source version)
-        foreach my $proc ($group->get_processables('binary')){
-            return if($proc->pkg_name eq $fpkg);
+        foreach my $processable ($group->get_processables('binary')){
+            return if($processable->name eq $fpkg);
         }
         # It was not, but since the source package was not present, we cannot
         # tell if it is foreign or not at this point.
