@@ -19,17 +19,20 @@
 # MA 02110-1301, USA.
 
 package Lintian::group_checks;
+
 use strict;
 use warnings;
 use autodie;
 
 use List::MoreUtils qw(any);
-use Moo;
 
 use Lintian::Data;
 use Lintian::Relation;
 
-with('Lintian::Check');
+use Moo;
+use namespace::clean;
+
+with 'Lintian::Check';
 
 my $KNOWN_DBG_PACKAGE = Lintian::Data->new('common/dbg-pkg',qr/\s*\~\~\s*/,
     sub { return qr/$_[0]/xms; });
@@ -52,15 +55,15 @@ sub source {
 
     $self->check_file_overlap(@procs);
 
-    foreach my $proc (@procs) {
-        my $deps = $ginfo->direct_dependencies($proc);
+    foreach my $processable (@procs) {
+        my $deps = $ginfo->direct_dependencies($processable);
         if (scalar @$deps > 0) {
             # it depends on another package - it can cause
             # a circular dependency
-            my $pname = $proc->pkg_name;
+            my $pname = $processable->name;
             push @nodes, $pname;
-            $edges{$pname} = [map { $_->pkg_name } @$deps];
-            $self->check_multiarch($proc, $deps);
+            $edges{$pname} = [map { $_->name } @$deps];
+            $self->check_multiarch($processable, $deps);
         }
     }
 
@@ -82,30 +85,30 @@ sub source {
 sub check_file_overlap {
     my ($self, @procs) = @_;
     # Sort them for stable output
-    my @sorted = sort { $a->pkg_name cmp $b->pkg_name } @procs;
+    my @sorted = sort { $a->name cmp $b->name } @procs;
     for (my $i = 0 ; $i < scalar @sorted ; $i++) {
-        my $proc = $sorted[$i];
-        my $pinfo = $proc->info;
-        my @p = grep { $_ } split(m/,/o, $pinfo->field('provides', ''));
-        my $prov = Lintian::Relation->new(join(' |̈́ ', $proc->pkg_name, @p));
+        my $processable = $sorted[$i];
+
+        my @p = grep { $_ } split(m/,/o, $processable->field('provides', ''));
+        my $prov
+          = Lintian::Relation->new(join(' |̈́ ', $processable->name, @p));
         for (my $j = $i ; $j < scalar @sorted ; $j++) {
             my $other = $sorted[$j];
-            my $oinfo = $other->info;
-            my @op = grep { $_ } split(m/,/o, $oinfo->field('provides', ''));
-            my $oprov
-              = Lintian::Relation->new(join(' | ', $other->pkg_name, @op));
+
+            my @op = grep { $_ } split(m/,/o, $other->field('provides', ''));
+            my $oprov= Lintian::Relation->new(join(' | ', $other->name, @op));
             # poor man's "Multi-arch: same" work-around.
-            next if $proc->pkg_name eq $other->pkg_name;
+            next if $processable->name eq $other->name;
 
-            # $other conflicts/replaces with $proc
-            next if $oinfo->relation('conflicts')->implies($prov);
-            next if $oinfo->relation('replaces')->implies($proc->pkg_name);
+            # $other conflicts/replaces with $processable
+            next if $other->relation('conflicts')->implies($prov);
+            next if $other->relation('replaces')->implies($processable->name);
 
-            # $proc conflicts/replaces with $other
-            next if $pinfo->relation('conflicts')->implies($oprov);
-            next if $pinfo->relation('replaces')->implies($other->pkg_name);
+            # $processable conflicts/replaces with $other
+            next if $processable->relation('conflicts')->implies($oprov);
+            next if $processable->relation('replaces')->implies($other->name);
 
-            $self->overlap_check($proc, $pinfo, $other, $oinfo);
+            $self->overlap_check($processable, $processable, $other, $other);
         }
     }
     return;
@@ -120,39 +123,39 @@ sub overlap_check {
         $b_file = $b_info->index($name) // $b_info->index("$name/");
         if ($b_file) {
             next if $a_file->is_dir and $b_file->is_dir;
-            $self->tag('binaries-have-file-conflict', $a_proc->pkg_name,
-                $b_proc->pkg_name, $name);
+            $self->tag('binaries-have-file-conflict',
+                $a_proc->name,$b_proc->name, $name);
         }
     }
     return;
 }
 
 sub check_multiarch {
-    my ($self, $proc, $deps) = @_;
+    my ($self, $processable, $deps) = @_;
 
-    my $ma = $proc->info->field('multi-arch', 'no');
+    my $ma = $processable->field('multi-arch', 'no');
     if ($ma eq 'same') {
         foreach my $dep (@$deps) {
-            my $dma = $dep->info->field('multi-arch', 'no');
+            my $dma = $dep->field('multi-arch', 'no');
             if ($dma eq 'same' or $dma eq 'foreign') {
                 1; # OK
             } else {
                 $self->tag(
                     'dependency-is-not-multi-archified',
                     join(q{ },
-                        $proc->pkg_name, 'depends on',
-                        $dep->pkg_name, "(multi-arch: $dma)"));
+                        $processable->name, 'depends on',
+                        $dep->name, "(multi-arch: $dma)"));
             }
         }
     } elsif ($ma ne 'same'
-        and $proc->info->field('section', 'none') =~ m,(?:^|/)debug$,o) {
+        and $processable->field('section', 'none') =~ m,(?:^|/)debug$,o) {
         # Debug package that isn't M-A: same, exploit that (non-debug)
         # dependencies is (almost certainly) a package for which the
         # debug carries debug symbols.
         foreach my $dep (@$deps) {
-            my $dma = $dep->info->field('multi-arch', 'no');
+            my $dma = $dep->field('multi-arch', 'no');
             if (    $dma eq 'same'
-                and $dep->info->field('section', 'none') !~ m,(?:^|/)debug$,o){
+                and $dep->field('section', 'none') !~ m,(?:^|/)debug$,o){
 
                 # Debug package isn't M-A: same, but depends on a
                 # package that is from same source that isn't a debug
@@ -161,9 +164,9 @@ sub check_multiarch {
                 # (architecture) variants of the binaries.
                 $self->tag(
                     'debug-package-for-multi-arch-same-pkg-not-coinstallable',
-                    $proc->pkg_name . ' => ' . $dep->pkg_name
+                    $processable->name . ' => ' . $dep->name
                   )
-                  unless any { $proc->pkg_name =~ m/$_/xms }
+                  unless any { $processable->name =~ m/$_/xms }
                 $KNOWN_DBG_PACKAGE->all;
             }
         }
